==> haskell-doctemplates-0.11-68-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.11
visibility:           public
id:                   doctemplates-0.11-LIg2qFsvfRLA8R2PGcxGiX
key:                  doctemplates-0.11-LIg2qFsvfRLA8R2PGcxGiX
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  e5756a0cf836736568677195c5219a5b
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11-LIg2qFsvfRLA8R2PGcxGiX
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    containers-0.6.5.1 doclayout-0.4.0.1-46hZ9EdFXbJ1TXJggbU79
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.15.0
    safe-0.3.21-iv9yHEgDynJNZkwcC9KXL
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc text-1.2.5.0
    text-conversions-0.3.1.1-HyoBJNnA8siJJce0oOJneZ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.11-77-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.11
visibility:           public
id:                   doctemplates-0.11-C27zRlWEVxT91PVtji9RxN
key:                  doctemplates-0.11-C27zRlWEVxT91PVtji9RxN
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  b71c62a670c861276425cc5f84b227d0
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11-C27zRlWEVxT91PVtji9RxN
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    containers-0.6.5.1 doclayout-0.4.0.1-IxeDl9AwMnpIQPfei6hK0V
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.15.0
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0
    text-conversions-0.3.1.1-Ds2ki1S0HMMH7HuRG1aZYm
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
